package com.xy.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import com.xy.annotate.RestMappingController;
import com.xy.dto.DeviceAlgorithmChargingDto;
import com.xy.dto.DeviceAlgorithmChargingHistoryDto;
import com.xy.dto.DeviceSimChargeDto;
import com.xy.service.DeviceAlgorithmChargingHistoryServiceImpl;
import com.xy.service.DeviceAlgorithmChargingServiceImpl;
import com.xy.util.ExcelUtils;
import com.xy.utils.MercAuthUtils;
import com.xy.utils.PageBean;
import com.xy.utils.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

@AllArgsConstructor
@Api(tags = "小程序-设备算法计费表")
@RestMappingController("merc-mini/deviceAlgorithmChargingHis")
public class DeviceAlgorithmChargingHisController {

    private DeviceAlgorithmChargingHistoryServiceImpl deviceAlgorithmChargingHistoryService;

    @PostMapping("pageByTopMerc")
    @ApiOperation("商管端-顶级商户设备激活明细查询")
    public R<PageBean<DeviceAlgorithmChargingHistoryDto.PageByTopMercVO>> pageByTopMerc(@RequestBody @Validated DeviceAlgorithmChargingHistoryDto.PageByTopMerc page) {
        page.setCurMercId(MercAuthUtils.getMercId());
        return deviceAlgorithmChargingHistoryService.pageByTopMerc(page);
    }

    @ApiOperation("顶级商户导设备激活算法费用明细")
    @PostMapping("exportPageByTopMerc")
    public void exportPageByTopMerc(HttpServletResponse response, @RequestBody @Valid DeviceAlgorithmChargingHistoryDto.PageByTopMerc page) throws IOException {
        page.setCurMercId(MercAuthUtils.getMercId());
        R<PageBean<DeviceAlgorithmChargingHistoryDto.PageByTopMercVO>> data = deviceAlgorithmChargingHistoryService.pageByTopMerc(page);
        List<DeviceAlgorithmChargingHistoryDto.PageByTopMercVO> records = data.getData().getRecords();
        if (CollUtil.isNotEmpty(records)) {
            for (DeviceAlgorithmChargingHistoryDto.PageByTopMercVO record : records) {
                Integer status = record.getStatus();
                if (status.intValue() != 2) {
                    record.setCreateTime(null);
                }
            }
        }
        List<DeviceAlgorithmChargingHistoryDto.PageExcelVo> deviceExcelVOS = BeanUtil.copyToList(records, DeviceAlgorithmChargingHistoryDto.PageExcelVo.class);
        // 输出
        ExcelUtils.write(response, "设备激活算法费用明细.xls", "设备激活算法费明细", DeviceAlgorithmChargingHistoryDto.PageExcelVo.class, deviceExcelVOS);
    }

}
